==> haskell-hslua-objectorientation-2.3.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.1
visibility:           public
id:                   hslua-objectorientation-2.3.1-3w1FTmeRHh8GY0s52lgXGE
key:                  hslua-objectorientation-2.3.1-3w1FTmeRHh8GY0s52lgXGE
license:              MIT
copyright:            © 2021-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  da0eba6377f5543a42b19436cadc6809
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.1-3w1FTmeRHh8GY0s52lgXGE
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.2-Hcy0ZlW6T6zmJvTSClvzp
    hslua-marshalling-2.3.1-IbxKG5Z0YdcCoFEGqnqrS4
    hslua-typing-0.1.1-EsbNGPOVs1jCZiiishvfRd mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.1
visibility:           public
id:                   hslua-objectorientation-2.3.1-KhfWxLNwE393xbRVFP8oxy
key:                  hslua-objectorientation-2.3.1-KhfWxLNwE393xbRVFP8oxy
license:              MIT
copyright:            © 2021-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  50f8e710001abbf3464fea35923472bc
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.1-KhfWxLNwE393xbRVFP8oxy
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.2-9l6Sx3VZLJD3bu6963Ci0b
    hslua-marshalling-2.3.1-5SlRGqQ3reCCx6I4xrLXlK
    hslua-typing-0.1.1-1wUHq9gk67xBzaexg53gLN mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
